@@ -298,24 +298,6 @@ def delta_seconds(before, after):
     return delta.total_seconds()
 
 
-@removals.remove(
-    message="use datetime.timedelta.total_seconds()",
-    version="3.1",
-    removal_version="?",
-    )
-def total_seconds(delta):
-    """Return the total seconds of datetime.timedelta object.
-
-    Compute total seconds of datetime.timedelta, datetime.timedelta
-    doesn't have method total_seconds in Python2.6, calculate it manually.
-    """
-    try:
-        return delta.total_seconds()
-    except AttributeError:
-        return ((delta.days * 24 * 3600) + delta.seconds +
-                float(delta.microseconds) / (10 ** 6))
-
-
 def is_soon(dt, window):
     """Determines if time is going to happen in the next window seconds.
 
